@@ -26,6 +26,16 @@ from ..utils.misc import normalize_mc_params
 IFLOGGER = logging.getLogger('nipype.interface')
 
 
+def fallback_svd(a, full_matrices=True, compute_uv=True):
+    try:
+        return np.linalg.svd(a, full_matrices=full_matrices, compute_uv=compute_uv)
+    except np.linalg.LinAlgError:
+        pass
+
+    from scipy.linalg import svd
+    return svd(a, full_matrices=full_matrices, compute_uv=compute_uv, lapack_driver='gesvd')
+
+
 class ComputeDVARSInputSpec(BaseInterfaceInputSpec):
     in_file = File(
         exists=True, mandatory=True, desc='functional data, after HMC')
@@ -271,7 +281,7 @@ class FramewiseDisplacement(BaseInterface):
     .. [Power2012] Power et al., Spurious but systematic correlations in functional
          connectivity MRI networks arise from subject motion, NeuroImage 59(3),
          2012. doi:`10.1016/j.neuroimage.2011.10.018
-         <http://dx.doi.org/10.1016/j.neuroimage.2011.10.018>`_.
+         <https://doi.org/10.1016/j.neuroimage.2011.10.018>`_.
 
 
     """
@@ -789,8 +799,9 @@ class TSNR(BaseInterface):
         meanimg = np.mean(data, axis=3)
         stddevimg = np.std(data, axis=3)
         tsnr = np.zeros_like(meanimg)
-        tsnr[stddevimg > 1.e-3] = meanimg[stddevimg > 1.e-3] / stddevimg[
-            stddevimg > 1.e-3]
+        stddevimg_nonzero = stddevimg > 1.e-3
+        tsnr[stddevimg_nonzero] = meanimg[stddevimg_nonzero] / stddevimg[
+            stddevimg_nonzero]
         img = nb.Nifti1Image(tsnr, img.affine, header)
         nb.save(img, op.abspath(self.inputs.tsnr_file))
         img = nb.Nifti1Image(meanimg, img.affine, header)
@@ -1191,7 +1202,7 @@ def compute_noise_components(imgseries, mask_images, num_components,
         # "The covariance matrix C = MMT was constructed and decomposed into its
         # principal components using a singular value decomposition."
         try:
-            u, _, _ = np.linalg.svd(M, full_matrices=False)
+            u, _, _ = fallback_svd(M, full_matrices=False)
         except np.linalg.LinAlgError:
             if self.inputs.failure_mode == 'error':
                 raise
@@ -1273,7 +1284,7 @@ def _full_rank(X, cmax=1e15):
     X: array of shape(nrows, ncols) after regularization
     cmax=1.e-15, float tolerance for condition number
     """
-    U, s, V = np.linalg.svd(X, 0)
+    U, s, V = fallback_svd(X, full_matrices=False)
     smax, smin = s.max(), s.min()
     c = smax / smin
     if c < cmax:
